//! A module containing helpful services that go beyond headers and messages.
//!

#[doc(hidden)]
pub mod digest_generator;

pub use digest_generator::DigestGenerator;
